import {Component, OnInit} from '@angular/core';
import {CalendarEntry} from "../calendar-entry";
import * as Lodash from 'lodash';

@Component({
  selector: 'app-calendar-view',
  templateUrl: './calendar-view.component.html',
  styleUrls: ['./calendar-view.component.css']
})
export class CalendarViewComponent implements OnInit {
  currentYear: number;
  rows: CalendarEntry[][] = [];
  month = "";
  private currentMonth: number;

  constructor() {
    const date: Date = new Date()
    this.currentMonth = date.getMonth()
    this.currentYear = date.getFullYear()
  }

  ngOnInit(): void {
    this.rows = this.getCalendarRows()
    this.updateMonth()
  }

  nextMonth(): void {
    const newMonth = this.currentMonth + 1;
    if (newMonth > 11) {
      this.currentYear++
      this.currentMonth = 0
    } else {
      this.currentMonth = newMonth
    }
    this.updateMonth()
    this.rows = this.getCalendarRows()
  }

  previousMonth(): void {
    const newMonth = this.currentMonth - 1;
    if (newMonth < 0) {
      this.currentYear--
      this.currentMonth = 11
    } else {
      this.currentMonth = newMonth
    }
    this.updateMonth()
    this.rows = this.getCalendarRows()
  }

  private updateMonth(): void {
    this.month = new Date(this.currentYear, this.currentMonth).toLocaleString('default', {month: 'long'});
  }

  private getCalendarRows(): CalendarEntry[][] {
    const daysInMonth: Date[] = this.getDaysInMonth()
    const firstDay: Date = daysInMonth[0]
    const paddingEntries: Date[] = []
    for (let i = 0; i < firstDay.getDay() - 1; i++) {
      paddingEntries.push(new Date(0))
    }
    const dayValues = paddingEntries.concat(daysInMonth)
      .map((value) => {
        return <CalendarEntry>
          {
            display: value.getFullYear() != 1970,
            date: value
          }
      })
    return Lodash.chunk(dayValues, 7)
  }

  private getDaysInMonth(): Date[] {
    const date = new Date(this.currentYear, this.currentMonth, 1);
    const days = [];
    while (date.getMonth() === this.currentMonth) {
      days.push(new Date(date));
      date.setDate(date.getDate() + 1);
    }
    return days;
  }

}
