import {Injectable} from '@angular/core';
import {MatDialog} from "@angular/material/dialog";
import {HttpErrorResponse} from "@angular/common/http";
import {ErrorAlertDialogComponent} from "./error-alert-dialog/error-alert-dialog.component";

@Injectable({
  providedIn: 'root'
})
export class ErrorHandlerService {

  handleRetrievalError(error: any, matDialog: MatDialog, object: string): void {
    this.handleError(error, matDialog, object, "retrieving")
  }

  handleWritingError(error: any, matDialog: MatDialog, object: string): void {
    this.handleError(error, matDialog, object, "writing")
  }

  handleDeletionError(error: any, matDialog: MatDialog, object: string): void {
    this.handleError(error, matDialog, object, "deleting")
  }

  private handleError(error: any, matDialog: MatDialog, object: string, operation: string): void {
    if (error instanceof HttpErrorResponse) {
      matDialog.open(ErrorAlertDialogComponent, {
        data: {
          message: `There was an error while ${operation} data for ${object}:\n${error.message}`,
          title: "HTTP Error"
        }
      })
    }
  }
}
