import {Injectable} from '@angular/core';
import {HttpClient, HttpErrorResponse} from "@angular/common/http";
import {WakeupTime} from "./wakeup-time";
import {catchError, Observable, of} from "rxjs";
import { environment } from '../environments/environment';

@Injectable({
  providedIn: 'root'
})
export class WakeupTimeService {
  private readonly URL_BASE: string = environment.apiUrl;

  constructor(private httpClient: HttpClient) {
  }

  getWakeupTime(identifier: string): Observable<WakeupTime | undefined> {
    return this.httpClient.get<WakeupTime>(this.URL_BASE + "/" + identifier)
      .pipe(
        catchError(this.handleError<WakeupTime>(undefined))
      );
  }

  setWakeupTime(identifier: string, wakeUpTime: WakeupTime) {
    return this.httpClient.put(this.URL_BASE + "/" + identifier, wakeUpTime)
  }

  deleteWakeupTime(identifier: string) {
    return this.httpClient.delete(this.URL_BASE + "/" + identifier)
  }

  deactivateWakeupTime(identifier: string) {
    return this.httpClient.put(this.URL_BASE + "/" + identifier, {})
  }

  private handleError<T>(result?: WakeupTime) {
    return (error: any): Observable<T> => {
      if (error instanceof HttpErrorResponse && error.status == 404) {
        return of(result as T)
      }

      throw(error)
    };
  }
}
